@@ -1,3 +1,4 @@
+from django.contrib.postgres.fields import JSONField
 from django.utils import timezone
 from django.db import models
 
@@ -25,7 +26,7 @@ class Token(models.Model):
     icon = models.ImageField(null=True, blank=True)
     is_nft = models.BooleanField(default=False)
     nft_description = models.CharField(max_length=255, default='')
-    nft_types = models.JSONField(default=dict)
+    nft_types = JSONField(default=dict)
     '''
         NFT_TYPES
         {
